@@ -28,7 +28,7 @@ typedef Eo Efl_Ui_Focus_Layer;
  */
 #define EFL_UI_FOCUS_LAYER_MIXIN efl_ui_focus_layer_mixin_get()
 
-EWAPI const Efl_Class *efl_ui_focus_layer_mixin_get(void);
+EAPI EAPI_WEAK const Efl_Class *efl_ui_focus_layer_mixin_get(void) EINA_CONST;
 
 #ifdef EFL_UI_FOCUS_LAYER_PROTECTED
 /**
@@ -41,7 +41,7 @@ EWAPI const Efl_Class *efl_ui_focus_layer_mixin_get(void);
  *
  * @ingroup Efl_Ui_Focus_Layer
  */
-EOAPI void efl_ui_focus_layer_enable_set(Eo *obj, Eina_Bool v);
+EAPI EAPI_WEAK void efl_ui_focus_layer_enable_set(Eo *obj, Eina_Bool v);
 #endif
 
 #ifdef EFL_UI_FOCUS_LAYER_PROTECTED
@@ -56,7 +56,7 @@ EOAPI void efl_ui_focus_layer_enable_set(Eo *obj, Eina_Bool v);
  *
  * @ingroup Efl_Ui_Focus_Layer
  */
-EOAPI Eina_Bool efl_ui_focus_layer_enable_get(const Eo *obj);
+EAPI EAPI_WEAK Eina_Bool efl_ui_focus_layer_enable_get(const Eo *obj);
 #endif
 
 #ifdef EFL_UI_FOCUS_LAYER_PROTECTED
@@ -71,7 +71,7 @@ EOAPI Eina_Bool efl_ui_focus_layer_enable_get(const Eo *obj);
  *
  * @ingroup Efl_Ui_Focus_Layer
  */
-EOAPI void efl_ui_focus_layer_behaviour_set(Eo *obj, Eina_Bool enable_on_visible, Eina_Bool cycle);
+EAPI EAPI_WEAK void efl_ui_focus_layer_behaviour_set(Eo *obj, Eina_Bool enable_on_visible, Eina_Bool cycle);
 #endif
 
 #ifdef EFL_UI_FOCUS_LAYER_PROTECTED
@@ -86,7 +86,7 @@ EOAPI void efl_ui_focus_layer_behaviour_set(Eo *obj, Eina_Bool enable_on_visible
  *
  * @ingroup Efl_Ui_Focus_Layer
  */
-EOAPI void efl_ui_focus_layer_behaviour_get(const Eo *obj, Eina_Bool *enable_on_visible, Eina_Bool *cycle);
+EAPI EAPI_WEAK void efl_ui_focus_layer_behaviour_get(const Eo *obj, Eina_Bool *enable_on_visible, Eina_Bool *cycle);
 #endif
 #endif /* EFL_BETA_API_SUPPORT */
 
